@@ -1,11 +1,11 @@
-from __future__ import unicode_literals
-
 import io
 import os
 import socket
 from unittest import TestCase
 from unittest.mock import patch
 
+import httpx
+import psutil
 import pytest
 
 from mocket import Mocket, MocketEntry, Mocketizer, mocketize
@@ -89,7 +89,7 @@ class MocketTestCase(TestCase):
         self.assertEqual(entry.get_response(), encode_to_bytes(""))
 
     def test_raise_exception(self):
-        entry = MocketEntry(("localhost", 8080), [IOError()])
+        entry = MocketEntry(("localhost", 8080), [OSError()])
 
         with self.assertRaises(IOError):
             entry.get_response()
@@ -144,16 +144,45 @@ class MocketTestCase(TestCase):
             self.assertEqual(fp.read().strip(), encode_to_bytes("Show me."))
             self.assertEqual(len(Mocket.request_list()), 1)
 
+    @pytest.mark.skipif(
+        'os.getenv("SKIP_TRUE_HTTP", False) or os.getenv("SKIP_TRUE_REDIS", False)'
+    )
+    def test_multiple_socket_connections(self):
+        redis_addr = ("localhost", 6379)
+        httpbin_addr = ("localhost", 80)
+
+        redis_buffer = io.BytesIO()
+        httpbin_buffer = io.BytesIO()
+
+        with Mocketizer():
+            redis_so = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+            redis_so.connect(redis_addr)
+
+            httpbin_so = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+            httpbin_so.connect(httpbin_addr)
+
+            # Creating another socket that connects to a different address
+            # should not cause the first connection to go awry.
+            redis_so.sendall(b"ping\r\n")
+            redis_so.recv_into(redis_buffer)
+
+            httpbin_so.sendall(b"GET / HTTP/1.1\r\nHost: localhost\r\n\r\n")
+            httpbin_so.recv_into(httpbin_buffer)
+
+        redis_buffer.seek(0)
+        assert redis_buffer.read() == b"+PONG\r\n"
+        httpbin_buffer.seek(0)
+        assert httpbin_buffer.read().startswith(b"HTTP/1.1 200 OK\r\n")
+
     def test_socket_as_context_manager(self):
         addr = ("localhost", 80)
         Mocket.register(MocketEntry(addr, ["Show me.\r\n"]))
-        with Mocketizer():
-            with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as _so:
-                _so.connect(addr)
-                _so.sendall(encode_to_bytes("Whatever..."))
-                data = _so.recv(4096)
-                self.assertEqual(data, encode_to_bytes("Show me.\r\n"))
-                self.assertEqual(str(_so), "(MocketSocket)(family=2 type=1 protocol=0)")
+        with Mocketizer(), socket.socket(socket.AF_INET, socket.SOCK_STREAM) as _so:
+            _so.connect(addr)
+            _so.sendall(encode_to_bytes("Whatever..."))
+            data = _so.recv(4096)
+            self.assertEqual(data, encode_to_bytes("Show me.\r\n"))
+            self.assertEqual(str(_so), "(MocketSocket)(family=2 type=1 protocol=0)")
 
 
 class MocketizeTestCase(TestCase):
@@ -180,7 +209,7 @@ def two():
 
 @mocketize
 def test_mocketize_with_fixture(two):
-    assert 2 == two
+    assert two == 2
 
 
 @mocketize
@@ -190,3 +219,18 @@ def test_patch(
 ):
     method_patch.return_value = "foo"
     assert os.getcwd() == "foo"
+
+
+@pytest.mark.skipif(not psutil.POSIX, reason="Uses a POSIX-only API to test")
+@pytest.mark.asyncio
+async def test_no_dangling_fds():
+    url = "http://httpbin.local/ip"
+
+    proc = psutil.Process(os.getpid())
+
+    prev_num_fds = proc.num_fds()
+
+    async with Mocketizer(strict_mode=False), httpx.AsyncClient() as client:
+        await client.get(url)
+
+    assert proc.num_fds() == prev_num_fds
